@@ -41,7 +41,7 @@
 #include <AppKit/NSSound.h>
 #include <AppKit/NSNibConnector.h>
 #include <AppKit/NSNibLoading.h>
-#include <GNUstepGUI/GSNibTemplates.h>
+#include <GNUstepGUI/GSGormLoading.h>
 #include "NSView+GormExtensions.h"
 #include "GormSound.h"
 #include "GormImage.h"
@@ -341,6 +341,7 @@ static NSImage  *fileImage = nil;
   // set up the toolbar...
   toolbar = [(NSToolbar *)[NSToolbar alloc] initWithIdentifier: @"GormToolbar"];
   [toolbar setAllowsUserCustomization: NO];
+  // [toolbar setSizeMode: NSToolbarSizeModeSmall];
   [toolbar setDelegate: self];
   [window setToolbar: toolbar];
   RELEASE(toolbar);
@@ -779,6 +780,20 @@ static NSImage  *fileImage = nil;
       id v = [ti view];
       [self attachObject: v toParent: ti];
     }
+  /*
+   * If it's a matrix, add the elements of the matrix.
+   */
+  else if ([anObject isKindOfClass: [NSMatrix class]])
+    {
+      NSCell *cell = nil;
+      NSEnumerator *en = [[anObject cells] objectEnumerator];
+      
+      // add all of the cells....
+      while((cell = [en nextObject]) != nil)
+	{
+	  [self attachObject: cell toParent: anObject];
+	}
+    }
   /*
    * If it's a simple NSView, add it and all of it's subviews.
    */
@@ -1160,6 +1175,18 @@ static NSImage  *fileImage = nil;
   NSDebugLog(@"Owner changed for %@", sender);
 }
 
+- (void) release
+{
+  [super release];
+}
+
+- (id) retain
+{
+  [super retain];
+  NSDebugLog(@"Retaining document, retain count %d",[self retainCount]);
+  return self;
+}
+
 /**
  * Dealloc all things owned by a GormDocument object.
  */
@@ -1167,15 +1194,14 @@ static NSImage  *fileImage = nil;
 {
   [[NSNotificationCenter defaultCenter] removeObserver: self];
   ASSIGN(lastEditor, nil);
+  // [filePrefsWindow close];
 
   // Get rid of the selection box.
-  [selectionBox removeFromSuperviewWithoutNeedingDisplay];
+  // [selectionBox removeFromSuperviewWithoutNeedingDisplay];
   
   RELEASE(classManager);
   RELEASE(filePrefsManager);
   RELEASE(filePrefsView);
-  RELEASE(savedEditors);
-  RELEASE(openEditors);
   RELEASE(hidden);
 
   if (objToName != 0)
@@ -1196,6 +1222,8 @@ static NSImage  *fileImage = nil;
   RELEASE(topLevelObjects);
   RELEASE(visibleWindows);
   RELEASE(deferredWindows);
+  DESTROY(savedEditors);
+  DESTROY(openEditors);
 
   TEST_RELEASE(scmWrapper);
   [super dealloc];
@@ -2806,10 +2834,10 @@ static void _real_close(GormDocument *self,
  */
 - (NSString *) description
 {
-  return [NSString stringWithFormat: @"<%s: %lx> = %@",
+  return [NSString stringWithFormat: @"<%s: %lx> = <<name table: %@, connections: %@>>",
 		   GSClassNameFromObject(self), 
 		   (unsigned long)self,
-		   nameTable];
+		   nameTable, connections];
 }
 
 /**
